summaryrefslogtreecommitdiffstats
path: root/src/extension/extension.cpp
diff options
context:
space:
mode:
authorLiam P. White <inkscapebrony@gmail.com>2014-10-06 00:18:46 +0000
committerLiam P. White <inkscapebrony@gmail.com>2014-10-06 00:18:46 +0000
commit7d38f876e8a4c5ab60261f61452fa2bf8baf13f3 (patch)
tree8d93f93ef7634ca78637b55edb9de4401669b2bb /src/extension/extension.cpp
parentAdd missing file to CMakeLists (diff)
parentRemove unused functions. (diff)
downloadinkscape-7d38f876e8a4c5ab60261f61452fa2bf8baf13f3.tar.gz
inkscape-7d38f876e8a4c5ab60261f61452fa2bf8baf13f3.zip
Update to trunk r13580
(bzr r13341.1.255)
Diffstat (limited to 'src/extension/extension.cpp')
-rw-r--r--src/extension/extension.cpp9
1 files changed, 7 insertions, 2 deletions
diff --git a/src/extension/extension.cpp b/src/extension/extension.cpp
index 06e35ff3e..6a22eb585 100644
--- a/src/extension/extension.cpp
+++ b/src/extension/extension.cpp
@@ -112,8 +112,13 @@ Extension::Extension (Inkscape::XML::Node * in_repr, Implementation::Implementat
_deps.push_back(new Dependency(child_repr));
} /* dependency */
if (!strcmp(chname, "script")) {
- _deps.push_back(new Dependency(child_repr->firstChild()));
- } /* check command as a dependency (see LP #505920) */
+ for (Inkscape::XML::Node *child = child_repr->firstChild(); child != NULL ; child = child->next()) {
+ if (child->type() == Inkscape::XML::ELEMENT_NODE) {
+ _deps.push_back(new Dependency(child));
+ break;
+ } /* skip non-element nodes (see LP #1372200) */
+ }
+ } /* check command as a dependency (see LP #505920) */
if (!strcmp(chname, "options")) {
silent = !strcmp( child_repr->attribute("silent"), "true" );
}